package com.bonus.canteen.core.alloc.service;

import java.util.List;
import com.bonus.canteen.core.alloc.domain.AllocCanteenEvaluate;

/**
 * 食堂评价Service接口
 * 
 * @author xsheng
 * @date 2025-04-14
 */
public interface IAllocCanteenEvaluateService {
    /**
     * 查询食堂评价
     * 
     * @param evaluateId 食堂评价主键
     * @return 食堂评价
     */
    public AllocCanteenEvaluate selectAllocCanteenEvaluateByEvaluateId(Long evaluateId);

    /**
     * 查询食堂评价列表
     * 
     * @param allocCanteenEvaluate 食堂评价
     * @return 食堂评价集合
     */
    public List<AllocCanteenEvaluate> selectAllocCanteenEvaluateList(AllocCanteenEvaluate allocCanteenEvaluate);

    /**
     * 新增食堂评价
     * 
     * @param allocCanteenEvaluate 食堂评价
     * @return 结果
     */
    public int insertAllocCanteenEvaluate(AllocCanteenEvaluate allocCanteenEvaluate);

    /**
     * 修改食堂评价
     * 
     * @param allocCanteenEvaluate 食堂评价
     * @return 结果
     */
    public int updateAllocCanteenEvaluate(AllocCanteenEvaluate allocCanteenEvaluate);

    /**
     * 批量删除食堂评价
     * 
     * @param evaluateIds 需要删除的食堂评价主键集合
     * @return 结果
     */
    public int deleteAllocCanteenEvaluateByEvaluateIds(Long[] evaluateIds);

    /**
     * 删除食堂评价信息
     * 
     * @param evaluateId 食堂评价主键
     * @return 结果
     */
    public int deleteAllocCanteenEvaluateByEvaluateId(Long evaluateId);
}
