package com.bonus.canteen.core.alloc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.alloc.domain.AllocCanteenEvaluate;
import com.bonus.canteen.core.alloc.service.IAllocCanteenEvaluateService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 食堂评价Controller
 * 
 * @author xsheng
 * @date 2025-04-14
 */
@Api(tags = "食堂评价接口")
@RestController
@RequestMapping("/alloc_canteen_evaluate")
public class AllocCanteenEvaluateController extends BaseController {
    @Autowired
    private IAllocCanteenEvaluateService allocCanteenEvaluateService;

    /**
     * 查询食堂评价列表
     */
    @ApiOperation(value = "查询食堂评价列表")
    //@RequiresPermissions("alloc:evaluate:list")
    @GetMapping("/list")
    public TableDataInfo list(AllocCanteenEvaluate allocCanteenEvaluate) {
        startPage();
        List<AllocCanteenEvaluate> list = allocCanteenEvaluateService.selectAllocCanteenEvaluateList(allocCanteenEvaluate);
        return getDataTable(list);
    }

    /**
     * 导出食堂评价列表
     */
    @ApiOperation(value = "导出食堂评价列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:evaluate:export")
    @SysLog(title = "食堂评价", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出食堂评价")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AllocCanteenEvaluate allocCanteenEvaluate) {
        List<AllocCanteenEvaluate> list = allocCanteenEvaluateService.selectAllocCanteenEvaluateList(allocCanteenEvaluate);
        ExcelUtil<AllocCanteenEvaluate> util = new ExcelUtil<AllocCanteenEvaluate>(AllocCanteenEvaluate.class);
        util.exportExcel(response, list, "食堂评价数据");
    }

    /**
     * 获取食堂评价详细信息
     */
    @ApiOperation(value = "获取食堂评价详细信息")
    //@RequiresPermissions("alloc:evaluate:query")
    @GetMapping(value = "/{evaluateId}")
    public AjaxResult getInfo(@PathVariable("evaluateId") Long evaluateId) {
        return success(allocCanteenEvaluateService.selectAllocCanteenEvaluateByEvaluateId(evaluateId));
    }

    /**
     * 新增食堂评价
     */
    @ApiOperation(value = "新增食堂评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:evaluate:add")
    @SysLog(title = "食堂评价", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增食堂评价")
    @PostMapping
    public AjaxResult add(@RequestBody AllocCanteenEvaluate allocCanteenEvaluate) {
        try {
            return toAjax(allocCanteenEvaluateService.insertAllocCanteenEvaluate(allocCanteenEvaluate));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改食堂评价
     */
    @ApiOperation(value = "修改食堂评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:evaluate:edit")
    @SysLog(title = "食堂评价", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改食堂评价")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AllocCanteenEvaluate allocCanteenEvaluate) {
        try {
            return toAjax(allocCanteenEvaluateService.updateAllocCanteenEvaluate(allocCanteenEvaluate));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除食堂评价
     */
    @ApiOperation(value = "删除食堂评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:evaluate:remove")
    @SysLog(title = "食堂评价", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除食堂评价")
	@PostMapping("/del/{evaluateIds}")
    public AjaxResult remove(@PathVariable Long[] evaluateIds) {
        return toAjax(allocCanteenEvaluateService.deleteAllocCanteenEvaluateByEvaluateIds(evaluateIds));
    }
}
